Index: /trunk/bp-blogs/bp-blogs-functions.php
===================================================================
--- /trunk/bp-blogs/bp-blogs-functions.php	(revision 5795)
+++ /trunk/bp-blogs/bp-blogs-functions.php	(revision 5796)
@@ -317,5 +317,5 @@
 		$key = $wpdb->get_blog_prefix( $blog_id ). 'capabilities';
 
-		$roles = get_user_meta( $user_id, $key, true );
+		$roles = bp_get_user_meta( $user_id, $key, true );
 
 		if ( is_array( $roles ) )
Index: /trunk/bp-forums/bp-forums-bbpress-sa.php
===================================================================
--- /trunk/bp-forums/bp-forums-bbpress-sa.php	(revision 5795)
+++ /trunk/bp-forums/bp-forums-bbpress-sa.php	(revision 5796)
@@ -102,5 +102,5 @@
 		$site_admins = get_site_option( 'site_admins', array('admin') );
 		foreach ( (array) $site_admins as $site_admin )
-			update_user_meta( bp_core_get_userid( $site_admin ), $bb_table_prefix . 'capabilities', array( 'keymaster' => true ) );
+			bp_update_user_meta( bp_core_get_userid( $site_admin ), $bb_table_prefix . 'capabilities', array( 'keymaster' => true ) );
 
 		// Create the first forum.
@@ -129,5 +129,5 @@
 		extract( $args, EXTR_SKIP );
 
-		return update_user_meta( $id, $meta_key, $meta_value );
+		return bp_update_user_meta( $id, $meta_key, $meta_value );
 	}
 }
Index: /trunk/bp-forums/bp-forums-functions.php
===================================================================
--- /trunk/bp-forums/bp-forums-functions.php	(revision 5795)
+++ /trunk/bp-forums/bp-forums-functions.php	(revision 5796)
@@ -611,5 +611,5 @@
 		return $allcaps;
 
-	$bb_cap = get_user_meta( bp_loggedin_user_id(), $bb_table_prefix . 'capabilities', true );
+	$bb_cap = bp_get_user_meta( bp_loggedin_user_id(), $bb_table_prefix . 'capabilities', true );
 
 	if ( empty( $bb_cap ) )
Index: /trunk/bp-members/bp-members-functions.php
===================================================================
--- /trunk/bp-members/bp-members-functions.php	(revision 5795)
+++ /trunk/bp-members/bp-members-functions.php	(revision 5796)
@@ -1074,10 +1074,10 @@
 	// Add the user's fullname to Xprofile
 	if ( bp_is_active( 'xprofile' ) ) {
-		$firstname = get_user_meta( $user_id, 'first_name', true );
-		$lastname = ' ' . get_user_meta( $user_id, 'last_name', true );
+		$firstname = bp_get_user_meta( $user_id, 'first_name', true );
+		$lastname = ' ' . bp_get_user_meta( $user_id, 'last_name', true );
 		$name = $firstname . $lastname;
 
 		if ( empty( $name ) || ' ' == $name )
-			$name = get_user_meta( $user_id, 'nickname', true );
+			$name = bp_get_user_meta( $user_id, 'nickname', true );
 
 		xprofile_set_field_data( 1, $user_id, $name );
Index: /trunk/bp-xprofile/bp-xprofile-classes.php
===================================================================
--- /trunk/bp-xprofile/bp-xprofile-classes.php	(revision 5795)
+++ /trunk/bp-xprofile/bp-xprofile-classes.php	(revision 5796)
@@ -290,5 +290,5 @@
 		
 		// Get the user's visibility level preferences
-		$visibility_levels = get_user_meta( $user_id, 'bp_xprofile_visibility_levels', true );
+		$visibility_levels = bp_get_user_meta( $user_id, 'bp_xprofile_visibility_levels', true );
 		
 		foreach( (array)$fields as $key => $field ) {
Index: /trunk/bp-xprofile/bp-xprofile-functions.php
===================================================================
--- /trunk/bp-xprofile/bp-xprofile-functions.php	(revision 5795)
+++ /trunk/bp-xprofile/bp-xprofile-functions.php	(revision 5796)
@@ -271,5 +271,5 @@
 	
 	// Stored in an array in usermeta
-	$current_visibility_levels = get_user_meta( $user_id, 'bp_xprofile_visibility_levels', true );
+	$current_visibility_levels = bp_get_user_meta( $user_id, 'bp_xprofile_visibility_levels', true );
 	
 	if ( !$current_visibility_levels ) {
@@ -279,5 +279,5 @@
 	$current_visibility_levels[$field_id] = $visibility_level;
 	
-	return update_user_meta( $user_id, 'bp_xprofile_visibility_levels', $current_visibility_levels );
+	return bp_update_user_meta( $user_id, 'bp_xprofile_visibility_levels', $current_visibility_levels );
 }
 
@@ -442,7 +442,7 @@
 	}
 
-	update_user_meta( $user_id, 'nickname',   $fullname  );
-	update_user_meta( $user_id, 'first_name', $firstname );
-	update_user_meta( $user_id, 'last_name',  $lastname  );
+	bp_update_user_meta( $user_id, 'nickname',   $fullname  );
+	bp_update_user_meta( $user_id, 'first_name', $firstname );
+	bp_update_user_meta( $user_id, 'last_name',  $lastname  );
 
 	$wpdb->query( $wpdb->prepare( "UPDATE {$wpdb->users} SET display_name = %s WHERE ID = %d", $fullname, $user_id ) );
@@ -476,6 +476,6 @@
  * @package BuddyPress XProfile
  * @param $user_id The ID of the deleted user
  * @uses get_user_meta() Get a user meta value based on meta key from wp_usermeta
  * @uses delete_user_meta() Delete user meta value based on meta key from wp_usermeta
  * @uses delete_data_for_user() Removes all profile data from the xprofile tables for the user
  */
@@ -484,12 +484,12 @@
 
 	// delete any avatar files.
-	@unlink( get_user_meta( $user_id, 'bp_core_avatar_v1_path', true ) );
-	@unlink( get_user_meta( $user_id, 'bp_core_avatar_v2_path', true ) );
+	@unlink( bp_get_user_meta( $user_id, 'bp_core_avatar_v1_path', true ) );
+	@unlink( bp_get_user_meta( $user_id, 'bp_core_avatar_v2_path', true ) );
 
 	// unset the usermeta for avatars from the usermeta table.
-	delete_user_meta( $user_id, 'bp_core_avatar_v1'      );
-	delete_user_meta( $user_id, 'bp_core_avatar_v1_path' );
-	delete_user_meta( $user_id, 'bp_core_avatar_v2'      );
-	delete_user_meta( $user_id, 'bp_core_avatar_v2_path' );
+	bp_delete_user_meta( $user_id, 'bp_core_avatar_v1'      );
+	bp_delete_user_meta( $user_id, 'bp_core_avatar_v1_path' );
+	bp_delete_user_meta( $user_id, 'bp_core_avatar_v2'      );
+	bp_delete_user_meta( $user_id, 'bp_core_avatar_v2_path' );
 }
 add_action( 'wpmu_delete_user',  'xprofile_remove_data' );
@@ -721,5 +721,5 @@
 	}
 	
-	$user_visibility_levels = get_user_meta( $user_id, 'bp_xprofile_visibility_levels', true );
+	$user_visibility_levels = bp_get_user_meta( $user_id, 'bp_xprofile_visibility_levels', true );
 	
 	$field_ids = array();
@@ -476,6 +476,6 @@
  * @package BuddyPress XProfile
  * @param $user_id The ID of the deleted user
- * @uses get_user_meta() Get a user meta value based on meta key from wp_usermeta
- * @uses delete_user_meta() Delete user meta value based on meta key from wp_usermeta
+ * @uses bp_get_user_meta() Get a user meta value based on meta key from wp_usermeta
+ * @uses bp_delete_user_meta() Delete user meta value based on meta key from wp_usermeta
  * @uses delete_data_for_user() Removes all profile data from the xprofile tables for the user
  */
